LINKS = {
    # Example
    'YotaPhone': 'http://yotaphone.com/',

    # Languages
    'Python': 'https://www.python.org/',
    'Java': 'http://www.java.com/',
    'Perl': 'http://perl.org/',
    'PHP': 'http://php.net/',
    'go': 'https://golang.org/',
    'golang': 'https://golang.org/',

    # OS
    'Linux': 'https://www.kernel.org/',
    'Debian': 'https://www.debian.org/',
    'Ubuntu': 'http://www.ubuntu.com/',
    'MacOS': 'http://www.apple.com/osx/',
    'Windows': 'http://windows.microsoft.com/',

    # DE
    'Qtile': 'http://qtile.org',

    # Databases
    'Postgres': 'http://www.postgresql.org/',
    'PostgreSQL': 'http://www.postgresql.org/',
    'sqlite': 'http://www.sqlite.org/',

    # NoSQL
    'CouchDB': 'http://couchdb.apache.org/',

    # Vendor
    'Apple': 'http://www.apple.com/',
    'Microsoft': 'http://microsoft.com/',
    'Digia': 'http://www.digia.com/',

    # WEB Frameworks
    'Django': 'https://www.djangoproject.com/',
    'Pylons': 'http://www.pylonsproject.org/',
    'Pyramid': 'http://www.pylonsproject.org/',
    'Flask': 'http://flask.pocoo.org/',
    'aiohttp': 'https://github.com/KeepSafe/aiohttp/',

    # Web server
    'nginx': 'http://nginx.org',
    'Apache': 'http://www.apache.org',

    # DE Frameworks
    'Qt': 'http://www.qt.io',
    'Qt4': 'http://www.qt.io',
    'Qt5': 'http://www.qt.io',

    # ORM
    'SQLAlchemy': 'http://www.sqlalchemy.org',

    # Template engine
    'Mako': 'http://docs.makotemplates.org/en/latest/',
    'Jinja': 'http://jinja.pocoo.org/',
    'Jinja2': 'http://jinja.pocoo.org/',

    # W3C
    'W3C': 'http://www.w3.org/',
    'CSS': 'http://www.w3.org/Style/CSS/',

    # JavaScript
    'JQuery': 'https://jquery.org/',

    # CVS
    'github': 'https://github.com/',

    # GIS
    'OpenStreetMap': 'http://www.openstreetmap.org',
    'OSM': 'http://www.openstreetmap.org',

    # packages
    'PyPi': 'https://pypi.python.org/',

    # editor
    'vi': 'http://www.vim.org',
    'vim': 'http://www.vim.org',

    # Virtualization
    'docker': 'http://docker.io/',
}
